@@ -1,6 +1,7 @@
 from ..context import AppContext
 from ..http.response import HttpResponse
 from ..routes.meta import RouteMeta
+from ..util import Logger, utils
 
 
 class MiddlewareManager:
@@ -14,10 +15,16 @@ class MiddlewareManager:
         self.request = request
         # 元数据信息
         self.meta = meta
+        self.logger = Logger.get(request.app_id)
 
     def handle_request(self):
         for middleware in self.context.middlewares:
-            result = middleware.process_request(self.request, self.meta)
+            try:
+                result = middleware.process_request(self.request, self.meta)
+            except Exception as e:
+                self.logger.error(utils.get_func_info(middleware.process_request), e)
+                break
+
             if isinstance(result, HttpResponse):
                 return result
             # 返回 None 以阻止后续中间件执行
@@ -30,7 +37,11 @@ class MiddlewareManager:
         :return:
         """
         for middleware in self.context.middlewares:
-            result = middleware.process_invoke(self.request, self.meta, args)
+            try:
+                result = middleware.process_invoke(self.request, self.meta, args)
+            except Exception as e:
+                self.logger.error(utils.get_func_info(middleware.process_invoke), e)
+                break
             if isinstance(result, HttpResponse):
                 return result
             # 返回 None 以阻止后续中间件执行
@@ -43,8 +54,12 @@ class MiddlewareManager:
         :param data:
         :return:
         """
-        for middleware in self.context.reversed_middlwares:
-            result = middleware.process_return(self.request, self.meta, data=data)
+        for middleware in self.context.reversed_middlewares:
+            try:
+                result = middleware.process_return(self.request, self.meta, data=data)
+            except Exception as e:
+                self.logger.error(utils.get_func_info(middleware.process_return), e)
+                break
 
             # 返回 HttpResponse 终止
             if result is HttpResponse:
@@ -65,8 +80,12 @@ class MiddlewareManager:
         :return:
         """
         # 对 response 进行处理
-        for middleware in self.context.reversed_middlwares:
-            new_response = middleware.process_response(self.request, self.meta, response=response)
+        for middleware in self.context.reversed_middlewares:
+            try:
+                new_response = middleware.process_response(self.request, self.meta, response=response)
+            except Exception as e:
+                self.logger.error(utils.get_func_info(middleware.process_response), e)
+                break
 
             if new_response is not None:
                 response = new_response
